Page 88 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 88

Home

    In the same year the Federal Reserve came into being,
    the Federal Income Tax also became law. It was sold to

    the American people with the inference that it would
    never be increased above the original 1 percent of
    income. The chief proponent of this legislation in
    Congress was also Senator Nelson Aldrich.

    Another important consideration for the members of
    the Money Trust was the establishment of tax-free

    foundations, whereby their own wealth would be
    sheltered from the income tax, and still be under their
    control. This was accomplished before the passage of the

    With the establishment of the Federal Reserve, private
    bankers had several means to control and use the money

    rr.

    wealth for themselves, but also to ‘extend the power of
    the Federal Government over the nation as a whole and

    over the people as individuals. One method repeatedly
    used has been the creation of "booms and busts" in the

    Reserve are above using their power for personal gain.
    This argument raises two important questions. The first
    question is, if that is the case, Why do they want this
    power? The second is, Why have they used this power
    repeatedly over a period of a century? For, it can be
    proven, that most of the booms and busts in the economy
    came "after" an action by the Federal Reserve, not

    83

    Building Modern Babylon

    income tax.

    system of the United States, not only to accumulate great

    economy, with those at the top knowing ahead of time

    what to expect of the money market. :

    It is argued that the men who control the Federal